@@ -52,3 +52,28 @@ void Client::SendStopListening(){
 
 	this->SendNetworkData_ts(p);
 }
+
+
+
+void Client::SendRegisterResult(ERegisterRes result){
+	Array<byte> p(2);
+
+	p[0] = 0x04; //register response
+
+	switch(result){
+		case REGISTERRES_SUCCESS:
+			p[1] = 0;
+			break;
+		case REGISTERRES_USERNAME_ALREADY_TAKEN:
+			p[1] = 1;
+			break;
+		default:
+		case REGISTERRES_SOME_ERROR:
+			p[1] = 3;
+			break;
+	}
+
+	//send response to client
+	this->SendNetworkData_ts(p);
+}
+
