@@ -184,7 +184,8 @@ class UserPasswordQueriedMessage : public ting::Message{
 public:
 	enum EResult{
 		SUCCESS,
-		USERNAME_NOT_FOUND
+		USERNAME_NOT_FOUND,
+		SOME_ERROR
 	};
 
 private:
