@@ -34,6 +34,12 @@ std::string Preferences::TimbreTypeToName(Preferences::E_Timbre timbre){
 		case PLUCKED_STRING:
 			return "PluckedString";
 			break;
+		case TROMBONE:
+			return "Trombone";
+			break;
+		case CLARINET:
+			return "Clarinet";
+			break;
 	}
 }
 
