@@ -79,6 +79,8 @@ public:
 	enum E_Timbre{
 		SINE_PLUS_ADSR,
 		PLUCKED_STRING,
+		TROMBONE,
+		CLARINET,
 
 		UNKNOWN, //NOTE: UNKNOWN must be last timbre in the list!!!
 
