@@ -257,7 +257,7 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 	this->lastVolume = this->volume;
 
 	ASSERT(this->instr)
-	Array<real> &sample = this->instr->sample;
+	const Array<real> &sample = this->instr->sample->data;
 	ASSERT(sample.Size() > 0)
 
 	real sustainLevel = this->instr->adsrParams.sustainLevel;
@@ -277,7 +277,7 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 					ASSERT(ting::uint(this->curPhase) < sample.Size())
 					s32 smp = s32(real(0x7fff) * attack * sample[ting::uint(this->curPhase)]);
 					this->curPhase += this->phaseStep;
-					if(ting::uint(this->curPhase) > sample.Size()){
+					if(ting::uint(this->curPhase) >= sample.Size()){
 						this->curPhase -= real(sample.Size());
 					}
 
@@ -310,7 +310,7 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 					ASSERT(ting::uint(this->curPhase) < sample.Size())
 					s32 smp = s32(real(0x7fff) * decay * sample[ting::uint(this->curPhase)]);
 					this->curPhase += this->phaseStep;
-					if(ting::uint(this->curPhase) > sample.Size()){
+					if(ting::uint(this->curPhase) >= sample.Size()){
 						this->curPhase -= real(sample.Size());
 					}
 					
@@ -349,13 +349,13 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 						ASSERT(ting::uint(this->curPhase) < sample.Size())
 						s32 smp = s32(real(0x7fff) * sustainLevel * sample[ting::uint(this->curPhase)]);
 						this->curPhase += this->phaseStep;
-						if(ting::uint(this->curPhase) > sample.Size()){
+						if(ting::uint(this->curPhase) >= sample.Size()){
 							this->curPhase -= real(sample.Size());
 						}
 
-//						this->curTime += 1.0f / float(44100);
 //						TRACE(<<"t =" << this->t)
-//						TRACE(<<"smp =" << smp)
+//						TRACE(<<"s =" << sample[ting::uint(this->curPhase)] << std::endl)
+//						TRACE(<<"smp =" << smp << std::endl)
 
 						//interpolate volume
 						ting::u8 vol = ting::u8(startVolume + (endVolume - startVolume) * i / mixBuf.Size());
@@ -377,7 +377,7 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 					ASSERT(ting::uint(this->curPhase) < sample.Size())
 					s32 smp = s32(real(0x7fff) * release * sample[ting::uint(this->curPhase)]);
 					this->curPhase += this->phaseStep;
-					if(ting::uint(this->curPhase) > sample.Size()){
+					if(ting::uint(this->curPhase) >= sample.Size()){
 						this->curPhase -= real(sample.Size());
 					}
 
@@ -423,3 +423,91 @@ Ref<Instrument::Channel> SampledInstrument::CreateChannel(){
 
 
 
+//static
+Ref<SampledInstrument::Sample> TromboneInstrument::GenerateSample(){
+	Ref<Sample> ret(new Sample());
+
+	//sampling rate 44100Hz, sound base freq is 25Hz
+	ret->freq = real(25);
+	ret->data.Init(44100 / ting::uint(ret->freq));//hold one period
+
+	Array<real> &d = ret->data;
+
+	typedef float T_Real;
+
+	float f = D2Pi<float>() * float(ret->freq);
+
+	for(ting::uint i = 0; i < ret->data.Size(); ++i){
+		ASSERT(i < d.Size())
+		float t = float(i) * float(1.0f / 44100.0f);
+		d[i] = real(
+				T_Real(0.002f)  * Cos(f * t)             + T_Real(-0.181f) * Sin(f * t) +
+				T_Real(-0.256f) * Cos(T_Real(2) * f * t) + T_Real(-0.128f) * Sin(T_Real(2) * f * t) +
+				T_Real(-0.177f) * Cos(T_Real(3) * f * t) + T_Real(0.122f)  * Sin(T_Real(3) * f * t) +
+				T_Real(-0.268f) * Cos(T_Real(4) * f * t) + T_Real(0.021f)  * Sin(T_Real(4) * f * t) +
+				T_Real(-0.056f) * Cos(T_Real(5) * f * t) + T_Real(0.034f)  * Sin(T_Real(5) * f * t) +
+				T_Real(0.010f)  * Cos(T_Real(6) * f * t) + T_Real(-0.024f) * Sin(T_Real(6) * f * t) +
+				T_Real(0.013f)  * Cos(T_Real(7) * f * t) + T_Real(0.000f)  * Sin(T_Real(7) * f * t) +
+				T_Real(0.001f)  * Cos(T_Real(8) * f * t) + T_Real(-0.004f) * Sin(T_Real(8) * f * t)
+			);
+	}
+
+	return ret;
+}
+
+
+
+SampledInstrument::ADSRParams TromboneInstrument::GetADSRParams(){
+	ADSRParams adsr = {
+		15, //attack
+		30, //decay
+		0.8, //sustainLevel
+		10 //release
+	};
+	return adsr;
+}
+
+
+
+//static
+Ref<SampledInstrument::Sample> ClarinetInstrument::GenerateSample(){
+	Ref<Sample> ret(new Sample());
+
+	//sampling rate 44100Hz, sound base freq is 25Hz
+	ret->freq = real(25);
+	ret->data.Init(44100 / ting::uint(ret->freq));//hold one period
+
+	Array<real> &d = ret->data;
+
+	typedef float T_Real;
+
+	float f = D2Pi<float>() * float(ret->freq);
+
+	for(ting::uint i = 0; i < ret->data.Size(); ++i){
+		ASSERT(i < d.Size())
+		float t = float(i) * float(1.0f / 44100.0f);
+		d[i] = real(
+				T_Real(-0.010f) * Cos(f * t)             + T_Real(0.077f)  * Sin(f * t) +
+				T_Real(-0.130f) * Cos(T_Real(3) * f * t) + T_Real(-0.005f) * Sin(T_Real(3) * f * t) +
+				T_Real(-0.210f) * Cos(T_Real(5) * f * t) + T_Real(0.134f)  * Sin(T_Real(5) * f * t) +
+				T_Real(-0.040f) * Cos(T_Real(6) * f * t) + T_Real(0.030f)  * Sin(T_Real(6) * f * t) +
+				T_Real(-0.050f) * Cos(T_Real(7) * f * t) + T_Real(-0.030f) * Sin(T_Real(7) * f * t) +
+				T_Real(-0.030f) * Cos(T_Real(9) * f * t) + T_Real(0.016f)  * Sin(T_Real(9) * f * t)
+			);
+	}
+
+	return ret;
+}
+
+
+
+SampledInstrument::ADSRParams ClarinetInstrument::GetADSRParams(){
+	ADSRParams adsr = {
+		10, //attack
+		10, //decay
+		0.8, //sustainLevel
+		20 //release
+	};
+	return adsr;
+}
+
