@@ -25,6 +25,7 @@ THE SOFTWARE. */
 #endif
 
 #include <gtkmm/main.h>
+#include <gtkmm/settings.h>
 
 #include <ting/debug.hpp>
 #include <ting/Fixed.hpp>
@@ -140,6 +141,9 @@ int main(int argc, char *argv[]){
 	// Initialize gtkmm:
 	Gtk::Main kit(&argc, &argv);
 
+	//TODO: add icons to buttons
+//	Gtk::Settings::get_default()->property_gtk_button_images() = true;
+
 	//create Glibdispatcher singleton
 	GlibDispatcher glibDispatcherSingleton;
 
